==============================
Popgen Pipeline Platform (PPP)
==============================

The PPP is a software platform with the goal of reducing the computational expertise required for conducting population genomic analyses. The PPP was designed as a collection of scripts that facilitate common population genomic workflows in a consistent and standardized environment. Functions were developed to encompass entire workflows, including: input preparation, file format conversion, various population genomic analyses, output generation, and visualization. By facilitating entire workflows, the PPP offers several benefits to prospective end users - it reduces the need of redundant in-house software and scripts that would require development time and may be error-prone, or incorrect, depending on the expertise of the investigator. The platform has also been developed with reproducibility and extensibility of analyses in mind.

The current documentation may be found `here <https://ppp.readthedocs.io/>`_. 

A PDF of the documentation is also available for `download <https://readthedocs.org/projects/ppp/downloads/pdf/latest/>`_. 


|build-status| |doc-status|



.. |build-status| image:: https://travis-ci.org/jaredgk/PPP.svg
    :alt: build status
    :scale: 100%
    :target: https://travis-ci.org/jaredgk/PPP
    
.. |doc-status| image:: https://readthedocs.org/projects/ppp/badge/?version=latest
    :alt: doc status
    :scale: 100%
    :target: https://ppp.readthedocs.io/en/latest/?badge=latest
